@@ -4,7 +4,7 @@
 //   Last updated on November 3, 2014
 //
 //   This file is part of Logtalk <http://logtalk.org/>  
-//   Copyright 1998-2015 Paulo Moura <pmoura@logtalk.org>
+//   Copyright 1998-2016 Paulo Moura <pmoura@logtalk.org>
 //   
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -68,8 +68,8 @@ else {
 	WScript.Quit(1);
 }
 
-var a4_xsl = logtalk_user + "\\xml\\lgtpdfa4.xsl";
-var us_xsl = logtalk_user + "\\xml\\lgtpdfus.xsl";
+var a4_xsl = logtalk_user + "\\tools\\lgtdoc\\xml\\logtalk_entity_to_pdf_a4.xsl";
+var us_xsl = logtalk_user + "\\tools\\lgtdoc\\xml\\logtalk_entity_to_pdf_us.xsl";
 var xsl;
 
 var f_arg = "";
@@ -113,16 +113,16 @@ if (format == "a4")
 else
 	xsl = us_xsl;
 
-if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk.dtd")) {
-	FSObject.CopyFile(logtalk_home + "\\xml\\logtalk.dtd", WshShell.CurrentDirectory + "\\logtalk.dtd");
+if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk_entity.dtd")) {
+	FSObject.CopyFile(logtalk_home + "\\tools\\lgtdoc\\xml\\logtalk_entity.dtd", WshShell.CurrentDirectory + "\\logtalk_entity.dtd");
 }
 
 if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\custom.ent")) {
-	FSObject.CopyFile(logtalk_home + "\\xml\\custom.ent", WshShell.CurrentDirectory + "\\custom.ent");
+	FSObject.CopyFile(logtalk_home + "\\tools\\lgtdoc\\xml\\custom.ent", WshShell.CurrentDirectory + "\\custom.ent");
 }
 
-if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk.xsd")) {
-	FSObject.CopyFile(logtalk_home + "\\xml\\logtalk.xsd", WshShell.CurrentDirectory + "\\logtalk.xsd");
+if (!FSObject.FileExists(WshShell.CurrentDirectory + "\\logtalk_entity.xsd")) {
+	FSObject.CopyFile(logtalk_home + "\\tools\\lgtdoc\\xml\\logtalk_entity.xsd", WshShell.CurrentDirectory + "\\logtalk_entity.xsd");
 }
 
 WScript.Echo("");
